---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**netty_snmp release version OR commit number**
ex. 1.0.0 OR abcd1234

**Operating System and Version**

- OS: [e.g. macOS, Ubuntu, RHEL, CentOS, Fedora, etc.]
- Version [e.g. 22]


**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.

**Do you have a fix already with working code**
Consider opening a PR with your fix. Ensure test coverage has been
added and that all Github actions pass.
